Documentation
¶
Index ¶
- Variables
- func RegisterShareServiceServer(s grpc.ServiceRegistrar, srv ShareServiceServer)
- type AddShareReq
- type AddShareResp
- type GetShareByPageReq
- func (*GetShareByPageReq) Descriptor() ([]byte, []int)deprecated
- func (x *GetShareByPageReq) GetLastId() string
- func (x *GetShareByPageReq) GetPageSize() int64
- func (*GetShareByPageReq) ProtoMessage()
- func (x *GetShareByPageReq) ProtoReflect() protoreflect.Message
- func (x *GetShareByPageReq) Reset()
- func (x *GetShareByPageReq) String() string
- type GetShareByPageResp
- func (*GetShareByPageResp) Descriptor() ([]byte, []int)deprecated
- func (x *GetShareByPageResp) GetData() []*PostItem
- func (x *GetShareByPageResp) GetLastId() string
- func (x *GetShareByPageResp) GetTotal() int64
- func (*GetShareByPageResp) ProtoMessage()
- func (x *GetShareByPageResp) ProtoReflect() protoreflect.Message
- func (x *GetShareByPageResp) Reset()
- func (x *GetShareByPageResp) String() string
- type PostItem
- func (*PostItem) Descriptor() ([]byte, []int)deprecated
- func (x *PostItem) GetCreatedAt() string
- func (x *PostItem) GetImg() []string
- func (x *PostItem) GetText() string
- func (x *PostItem) GetUpdatedAt() string
- func (*PostItem) ProtoMessage()
- func (x *PostItem) ProtoReflect() protoreflect.Message
- func (x *PostItem) Reset()
- func (x *PostItem) String() string
- type ShareServiceClient
- type ShareServiceServer
- type UnimplementedShareServiceServer
- type UnsafeShareServiceServer
Constants ¶
This section is empty.
Variables ¶
ServiceName: "ShareService", HandlerType: (*ShareServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "AddShare", Handler: _ShareService_AddShare_Handler, }, { MethodName: "GetShareByPage", Handler: _ShareService_GetShareByPage_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "share.proto", }
ShareService_ServiceDesc is the grpc.ServiceDesc for ShareService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterShareServiceServer ¶
func RegisterShareServiceServer(s grpc.ServiceRegistrar, srv ShareServiceServer)
Types ¶
type AddShareReq ¶
type AddShareReq struct {
// contains filtered or unexported fields
}
func (*AddShareReq) Descriptor
deprecated
func (*AddShareReq) Descriptor() ([]byte, []int)
Deprecated: Use AddShareReq.ProtoReflect.Descriptor instead.
func (*AddShareReq) GetPostContent ¶
func (x *AddShareReq) GetPostContent() *PostItem
func (*AddShareReq) ProtoMessage ¶
func (*AddShareReq) ProtoMessage()
func (*AddShareReq) ProtoReflect ¶
func (x *AddShareReq) ProtoReflect() protoreflect.Message
func (*AddShareReq) Reset ¶
func (x *AddShareReq) Reset()
func (*AddShareReq) String ¶
func (x *AddShareReq) String() string
type AddShareResp ¶
type AddShareResp struct {
// contains filtered or unexported fields
}
func (*AddShareResp) Descriptor
deprecated
func (*AddShareResp) Descriptor() ([]byte, []int)
Deprecated: Use AddShareResp.ProtoReflect.Descriptor instead.
func (*AddShareResp) GetMessage ¶
func (x *AddShareResp) GetMessage() string
func (*AddShareResp) ProtoMessage ¶
func (*AddShareResp) ProtoMessage()
func (*AddShareResp) ProtoReflect ¶
func (x *AddShareResp) ProtoReflect() protoreflect.Message
func (*AddShareResp) Reset ¶
func (x *AddShareResp) Reset()
func (*AddShareResp) String ¶
func (x *AddShareResp) String() string
type GetShareByPageReq ¶
type GetShareByPageReq struct {
// contains filtered or unexported fields
}
func (*GetShareByPageReq) Descriptor
deprecated
func (*GetShareByPageReq) Descriptor() ([]byte, []int)
Deprecated: Use GetShareByPageReq.ProtoReflect.Descriptor instead.
func (*GetShareByPageReq) GetLastId ¶
func (x *GetShareByPageReq) GetLastId() string
func (*GetShareByPageReq) GetPageSize ¶
func (x *GetShareByPageReq) GetPageSize() int64
func (*GetShareByPageReq) ProtoMessage ¶
func (*GetShareByPageReq) ProtoMessage()
func (*GetShareByPageReq) ProtoReflect ¶
func (x *GetShareByPageReq) ProtoReflect() protoreflect.Message
func (*GetShareByPageReq) Reset ¶
func (x *GetShareByPageReq) Reset()
func (*GetShareByPageReq) String ¶
func (x *GetShareByPageReq) String() string
type GetShareByPageResp ¶
type GetShareByPageResp struct {
// contains filtered or unexported fields
}
func (*GetShareByPageResp) Descriptor
deprecated
func (*GetShareByPageResp) Descriptor() ([]byte, []int)
Deprecated: Use GetShareByPageResp.ProtoReflect.Descriptor instead.
func (*GetShareByPageResp) GetData ¶
func (x *GetShareByPageResp) GetData() []*PostItem
func (*GetShareByPageResp) GetLastId ¶
func (x *GetShareByPageResp) GetLastId() string
func (*GetShareByPageResp) GetTotal ¶
func (x *GetShareByPageResp) GetTotal() int64
func (*GetShareByPageResp) ProtoMessage ¶
func (*GetShareByPageResp) ProtoMessage()
func (*GetShareByPageResp) ProtoReflect ¶
func (x *GetShareByPageResp) ProtoReflect() protoreflect.Message
func (*GetShareByPageResp) Reset ¶
func (x *GetShareByPageResp) Reset()
func (*GetShareByPageResp) String ¶
func (x *GetShareByPageResp) String() string
type PostItem ¶
type PostItem struct {
Text string `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
Img []string `protobuf:"bytes,2,rep,name=img,proto3" json:"img,omitempty"`
CreatedAt string `protobuf:"bytes,3,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt string `protobuf:"bytes,4,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*PostItem) Descriptor
deprecated
func (*PostItem) GetCreatedAt ¶
func (*PostItem) GetUpdatedAt ¶
func (*PostItem) ProtoMessage ¶
func (*PostItem) ProtoMessage()
func (*PostItem) ProtoReflect ¶
func (x *PostItem) ProtoReflect() protoreflect.Message
type ShareServiceClient ¶
type ShareServiceClient interface {
}
ShareServiceClient is the client API for ShareService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewShareServiceClient ¶
func NewShareServiceClient(cc grpc.ClientConnInterface) ShareServiceClient
type ShareServiceServer ¶
type ShareServiceServer interface {
// contains filtered or unexported methods
}
ShareServiceServer is the server API for ShareService service. All implementations must embed UnimplementedShareServiceServer for forward compatibility
type UnimplementedShareServiceServer ¶
type UnimplementedShareServiceServer struct {
}
UnimplementedShareServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedShareServiceServer) AddShare ¶
func (UnimplementedShareServiceServer) AddShare(context.Context, *AddShareReq) (*AddShareResp, error)
func (UnimplementedShareServiceServer) GetShareByPage ¶
func (UnimplementedShareServiceServer) GetShareByPage(context.Context, *GetShareByPageReq) (*GetShareByPageResp, error)
type UnsafeShareServiceServer ¶
type UnsafeShareServiceServer interface {
// contains filtered or unexported methods
}
UnsafeShareServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ShareServiceServer will result in compilation errors.